@@ -369,7 +369,7 @@ def _pdb_is_protein_model(path, max_bytes=32768):
 
 
 
-def _categorize_files(available_files, ligand_hints=None):
+def _categorize_files(available_files, ligand_hints=None, files_local=True):
     """
     Categorize files by type and purpose.
 
@@ -396,7 +396,11 @@ def _categorize_files(available_files, ligand_hints=None):
     # Filter out zero-byte, corrupt, or structurally invalid files before categorizing.
     # This ensures has_full_map / has_model etc. only reflect genuinely usable files,
     # which in turn makes not_has conditions (Category A) reliable.
-    available_files = [f for f in available_files if _is_valid_file(f)]
+    # Filter out zero-byte, corrupt, or structurally invalid files before categorizing.
+    # Skip on server where client files aren't on disk (would pass everything through
+    # anyway since _is_valid_file returns True for non-existent files).
+    if files_local:
+        available_files = [f for f in available_files if _is_valid_file(f)]
 
     # Try to load YAML rules
     category_rules = _load_category_rules()
@@ -405,7 +409,8 @@ def _categorize_files(available_files, ligand_hints=None):
         files = _categorize_files_yaml(available_files, category_rules)
     else:
         # Fallback to hardcoded rules if YAML not available
-        files = _categorize_files_hardcoded(available_files, ligand_hints=ligand_hints)
+        files = _categorize_files_hardcoded(available_files, ligand_hints=ligand_hints,
+                                            files_local=files_local)
 
     # Bubble up subcategories to their parent semantic categories
     files = _bubble_up_to_parents(files, category_rules)
@@ -458,6 +463,24 @@ def _categorize_files(available_files, ligand_hints=None):
     # Only files that are SOLELY in 'unclassified_pdb' are inspected here.
     # Files that have already matched a more specific model subcategory (refined,
     # phaser_output, docked, etc.) are left alone regardless of content.
+
+    # Pre-step: rescue known program outputs that ended up in unclassified_pdb.
+    # map_to_model*.pdb is the final output of phenix.map_to_model.  A partial
+    # cryo-EM build can have ≤150 atoms and trip _pdb_is_small_molecule.
+    # Reclassify as autobuild_output BEFORE the small-molecule check.
+    for f in list(files.get("unclassified_pdb", [])):
+        bn = os.path.basename(f).lower()
+        if 'map_to_model' in bn:
+            if "autobuild_output" not in files:
+                files["autobuild_output"] = []
+            if f not in files["autobuild_output"]:
+                files["autobuild_output"].append(f)
+            # Also ensure it's in "model" parent (may already be via bubble-up)
+            if "model" not in files:
+                files["model"] = []
+            if f not in files["model"]:
+                files["model"].append(f)
+
     _model_subcats = {
         "refined", "rsr_output", "phaser_output", "autobuild_output",
         "docked", "with_ligand", "ligand_fit_output", "model_cif",
@@ -467,7 +490,7 @@ def _categorize_files(available_files, ligand_hints=None):
         if any(f in files.get(sc, []) for sc in _model_subcats):
             continue
         # Primary: content inspection (works on client where files are on disk)
-        is_small = _pdb_is_small_molecule(f)
+        is_small = _pdb_is_small_molecule(f) if files_local else False
         # Fallback: client-side hints (works on server where files are NOT on disk)
         if not is_small and ligand_hints:
             is_small = os.path.basename(f) in ligand_hints
@@ -484,6 +507,73 @@ def _categorize_files(available_files, ligand_hints=None):
                 if f not in files[lst_key]:
                     files[lst_key].append(f)
 
+    # Post-processing: Validate ligand_pdb classification.
+    #
+    # The YAML categorizer (and potentially the hardcoded categorizer) may
+    # misclassify protein PDB files as ligands when broad patterns match
+    # filenames like 1aba.pdb, 3gx5.pdb, etc.  A real protein with a few
+    # HETATM ligand/cofactor atoms is still a macromolecular model, not a
+    # ligand coordinate file.
+    #
+    # Content inspection is the reliable tiebreaker: if a PDB file in
+    # ligand_pdb is predominantly ATOM records (i.e. _pdb_is_protein_model
+    # returns True), it is a false positive and should be reclassified as
+    # unclassified_pdb → model.
+    #
+    # Only runs when files are on local disk (files_local=True).
+    if files_local and files.get("ligand_pdb"):
+        ligand_keep = []
+        ligand_rescued = []
+        for f in files["ligand_pdb"]:
+            if f.lower().endswith('.pdb') and _pdb_is_protein_model(f):
+                ligand_rescued.append(f)
+            else:
+                ligand_keep.append(f)
+        if ligand_rescued:
+            files["ligand_pdb"] = ligand_keep
+            # Remove from ligand parent
+            for f in ligand_rescued:
+                if f in files.get("ligand", []):
+                    files["ligand"].remove(f)
+            # Add to unclassified_pdb + pdb + model
+            for dest in ("unclassified_pdb", "pdb", "model"):
+                if dest not in files:
+                    files[dest] = []
+                for f in ligand_rescued:
+                    if f not in files[dest]:
+                        files[dest].append(f)
+
+    # Post-processing: Validate half-map classification.
+    #
+    # Both the YAML and hardcoded categorizers can misclassify sequentially
+    # numbered maps (map_1.ccp4, map_2.ccp4 from resolve_cryo_em segmentation)
+    # as half-maps if broad patterns like *_[12].* are used.
+    #
+    # Half-maps from EMDB, RELION, CryoSPARC, and other cryo-EM software
+    # always contain 'half' in their filename.  Any file in half_map without
+    # 'half' in the name is reclassified as full_map.
+    if "half_map" in files and files["half_map"]:
+        reclassified = []
+        keep = []
+        for f in files["half_map"]:
+            if 'half' in os.path.basename(f).lower():
+                keep.append(f)
+            else:
+                reclassified.append(f)
+        if reclassified:
+            files["half_map"] = keep
+            if "full_map" not in files:
+                files["full_map"] = []
+            for f in reclassified:
+                if f not in files["full_map"]:
+                    files["full_map"].append(f)
+            # Also ensure reclassified files are in 'map' parent
+            if "map" not in files:
+                files["map"] = []
+            for f in reclassified:
+                if f not in files["map"]:
+                    files["map"].append(f)
+
     # Post-processing: If we have exactly one half-map and no full maps,
     # treat it as a full map. Half-maps only make sense in pairs for FSC.
     # A user providing a single map (even if named like a half-map) wants to use it.
@@ -826,7 +916,7 @@ def _categorize_files_yaml(available_files, rules):
     return files
 
 
-def _categorize_files_hardcoded(available_files, ligand_hints=None):
+def _categorize_files_hardcoded(available_files, ligand_hints=None, files_local=True):
     """
     Categorize files by type and purpose.
 
@@ -865,18 +955,18 @@ def _categorize_files_hardcoded(available_files, ligand_hints=None):
     xray_data_extensions = ('.mtz', '.sca', '.hkl', '.sdf')
 
     def is_half_map(basename):
-        """Detect if a map file is a half-map based on naming conventions."""
-        name_lower = basename.lower()
-        name_no_ext = os.path.splitext(name_lower)[0]
+        """Detect if a map file is a half-map based on naming conventions.
 
-        if 'half' in name_lower:
-            return True
-        if re.search(r'[_\-]?[12]$', name_no_ext):
-            return True
-        if re.search(r'[_\-][ab]$', name_no_ext):
-            return True
+        Only matches files with 'half' in the name (e.g. half_map_1.mrc,
+        half1.mrc, emd_12345_half_map_2.map).
 
-        return False
+        The old regexes [_-]?[12]$ and [_-][ab]$ were removed because
+        they false-positive on sequentially numbered maps like map_1.ccp4,
+        map_2.ccp4 (segmented maps from resolve_cryo_em), segment_a.mrc,
+        etc.  Real half-maps from EMDB, RELION, CryoSPARC, and other
+        cryo-EM software all contain 'half' in their filename.
+        """
+        return 'half' in basename.lower()
 
     # Import shared MTZ classification
     classify_mtz_type, get_mtz_stage = _import_mtz_utils()
@@ -903,27 +993,40 @@ def _categorize_files_hardcoded(available_files, ligand_hints=None):
             files["pdb"].append(f)
 
             # Subcategorize PDBs by their origin/purpose
+            # Track whether this PDB matched any known program-output subcategory.
+            # Files that match are known outputs and must NOT be reclassified as
+            # small molecules later (a small cryo-EM build can have ≤150 atoms
+            # and trip _pdb_is_small_molecule).
+            _is_program_output = False
+
             if 'phaser' in basename or basename.startswith('phaser'):
                 files["phaser_output"].append(f)
+                _is_program_output = True
 
             if 'refine' in basename and 'real_space' not in basename and 'rsr' not in basename:
                 files["refined"].append(f)
+                _is_program_output = True
 
             # RSR output detection - real_space_refine outputs contain 'real_space_refined'
             # e.g., model_real_space_refined_000.pdb
             if 'real_space_refined' in basename or 'rsr_' in basename or '_rsr' in basename:
                 files["rsr_output"].append(f)
+                _is_program_output = True
 
             if 'with_ligand' in basename:
                 files["with_ligand"].append(f)
+                _is_program_output = True
             if 'ligand_fit' in basename or 'ligandfit' in basename:
                 files["ligand_fit_output"].append(f)
+                _is_program_output = True
 
             if 'predict' in basename or 'alphafold' in basename or 'colabfold' in basename:
                 files["predicted"].append(f)
+                _is_program_output = True
 
             if 'processed' in basename:
                 files["processed_predicted"].append(f)
+                _is_program_output = True
 
             is_autobuild = (
                 ('autobuild' in basename or 'auto_build' in basename) or
@@ -936,12 +1039,24 @@ def _categorize_files_hardcoded(available_files, ligand_hints=None):
             )
             if is_autobuild and 'predict' not in basename:
                 files["autobuild_output"].append(f)
+                _is_program_output = True
+
+            # map_to_model output — the final positioned model from cryo-EM
+            # model building.  Matched by "map_to_model" in basename.  Must
+            # come AFTER the autobuild check (which catches generic 'build')
+            # and BEFORE the small-molecule check (a partial build with few
+            # atoms would otherwise be misclassified as a ligand).
+            if 'map_to_model' in basename:
+                files["autobuild_output"].append(f)
+                _is_program_output = True
 
             if 'dock' in basename and 'map' in basename:
                 files["docked"].append(f)
+                _is_program_output = True
             # Also match placed_model* from dock_in_map output
             if basename.startswith('placed_model') or '_placed' in basename:
                 files["docked"].append(f)
+                _is_program_output = True
 
             # Intermediate MR files from dock_in_map - never use for refinement
             if basename.startswith('run_mr') or fnmatch.fnmatch(basename, '*mr.[0-9]*'):
@@ -958,16 +1073,20 @@ def _categorize_files_hardcoded(available_files, ligand_hints=None):
             if _is_ligand_name:
                 if not any(x in basename for x in ['ligand_fit', 'ligandfit', 'with_ligand']):
                     files["ligand_pdb"].append(f)
-            else:
+            elif not _is_program_output:
                 # Content-based detection: HETATM-only files whose names don't
                 # contain 'lig' or 'ligand' (e.g. atp.pdb, gdp.pdb, hem.pdb).
                 # Primary: read PDB content (works on client where files are on disk).
                 # Fallback: client-side ligand_hints (works on server).
-                is_small = _pdb_is_small_molecule(f)
+                #
+                # CRITICAL: Only check files that didn't match any program-output
+                # subcategory above.  A small cryo-EM map_to_model output (≤150
+                # atoms) would otherwise be misclassified as a ligand.
+                is_small = _pdb_is_small_molecule(f) if files_local else False
                 if not is_small and ligand_hints:
                     is_small = os.path.basename(f) in ligand_hints
                 if is_small:
-                    # Remove from generic 'pdb' and add to ligand_pdb instead.
+                    # Move: pdb → ligand_pdb
                     files["pdb"].remove(f)
                     files["ligand_pdb"].append(f)
 
@@ -1639,7 +1758,8 @@ def _clear_zombie_done_flags(history_info, available_files, log_func=None):
 
 
 def detect_workflow_state(history, available_files, analysis=None, maximum_automation=True,
-                         use_yaml_engine=True, directives=None, session_info=None):
+                         use_yaml_engine=True, directives=None, session_info=None,
+                         files_local=True):
     """
     Determine current workflow state based on history and files.
 
@@ -1684,7 +1804,8 @@ def detect_workflow_state(history, available_files, analysis=None, maximum_autom
                                 ligand_hints.add(os.path.basename(v))
                     else:
                         ligand_hints.add(os.path.basename(val))
-    files = _categorize_files(available_files, ligand_hints=ligand_hints)
+    files = _categorize_files(available_files, ligand_hints=ligand_hints,
+                              files_local=files_local)
 
     # Analyze history
     history_info = _analyze_history(history)
@@ -1708,7 +1829,8 @@ def detect_workflow_state(history, available_files, analysis=None, maximum_autom
 
             engine = WorkflowEngine()
             state = engine.get_workflow_state(experiment_type, files, history_info, analysis,
-                                             directives, maximum_automation, session_info)
+                                             directives, maximum_automation, session_info,
+                                             files_local=files_local)
 
             state["categorized_files"] = state.get("categorized_files", files)  # S2c: respect promoted files
             # Set automation_path for both experiment types
